@@ -1,19 +1,24 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
-# This program is free software; you can redistribute it and/or modify
+# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2007 (C) Peter Gill - win32 parts
+
+# This file is part of DeVeDe
+#
+# DeVeDe is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# DeVeDe is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 
 ###########################################################################
 # This block contains generic help functions that are used in the program #
@@ -21,10 +26,12 @@
 
 import os
 import subprocess
+import stat
 import sys
+import shutil
 if sys.platform == 'win32':
-	import _winreg
-	import win32_helper
+	import win32process
+
 
 def separa_dnd(datos):
 
@@ -59,16 +66,18 @@ def separa_dnd(datos):
 def launch_program(program,salida=True):
 
 	""" Launchs a program that can be located in any of the directories stored in PATHLIST """
+	
+	curDir=sys.path[-1:] # Allow launching programs from local directory when use py2exe
 	pathlist=[]
 	if not sys.platform == 'win32':
 		pathlist=["/usr/bin","/usr/local/bin","/usr/share/bin","/usr/share/local/bin","/bin"]
 	else:
-		pathlist=[os.path.join(os.getcwd(),"bin"), r'C:\WINDOWS', r'C:\WINDOWS\system32', r'C:\WINNT']
-
+		pathlist=[os.path.join(curDir[0],"bin"), r'C:\WINDOWS', r'C:\WINDOWS\system32', r'C:\WINNT']
+	
 	print "Launching program:"
 	print "program: ",program
-	print
-
+	print "Current working Directory: ", os.getcwd()
+	
 	for elemento in pathlist:
 		#if elemento[-1]!="/":
 		print "elemento: ", elemento
@@ -82,7 +91,7 @@ def launch_program(program,salida=True):
 				#handle=subprocess.Popen(program2,executable=program[0],shell=False,bufsize=32768,stdout=subprocess.PIPE,stderr=subprocess.PIPE)
 				
 				if sys.platform=='win32':
-					handle=win32_helper.Popen(program2,executable=program2[0], shell=False,bufsize=32767,stdin=subprocess.PIPE, stdout=subprocess.PIPE)
+					handle=subprocess.Popen(program2,executable=program2[0], shell=False,bufsize=32767,stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, creationflags=win32process.CREATE_NO_WINDOW)
 				else:
 					handle=subprocess.Popen(program2,executable=program[0],shell=False,bufsize=32767,stdout=subprocess.PIPE,stderr=subprocess.PIPE)
 				
@@ -91,7 +100,7 @@ def launch_program(program,salida=True):
 				
 				if sys.platform=='win32':
 					print "b"
-					handle=win32_helper.Popen(program2,executable=program2[0],shell=False,stdin=subprocess.PIPE, stdout=subprocess.PIPE)
+					handle=subprocess.Popen(program2,executable=program2[0],shell=False,stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, creationflags=win32process.CREATE_NO_WINDOW)
 				else:
 					handle=subprocess.Popen(program2,executable=program[0],shell=False)
 				
@@ -99,10 +108,6 @@ def launch_program(program,salida=True):
 			print "error in launch program\n\n\n\n"
 			pass
 		else:
-			#if sys.platform!='win32':
-				# less priority to allow to use the computer without speed penalty while compressing
-			#	handler2=subprocess.Popen("renice 1 "+str(handle.pid),bufsize=8192,shell=True)
-			#	handler2.wait()
 			return handle
 	return None
 
@@ -131,11 +136,11 @@ def check_program(programa):
 	by calling it without arguments and checking the error returned """
 
 	#TODO switch /dev/null to windows compatable maybe "null"
-	if not sys.platform=='win32':
-		p=subprocess.Popen(programa+" >/dev/null 2>/dev/null",shell=True)
-	else:
-		#p=subprocess.Popen(programa)
+	if sys.platform=='win32':
 		p=launch_program(programa) # call in list form
+	else:
+		p=subprocess.Popen(programa+" >/dev/null 2>/dev/null",shell=True)
+
 
 	p.wait()
 	return p.returncode
@@ -146,21 +151,23 @@ def load_config(global_vars):
 	""" Load the configuration """
 	home=get_home_directory()
 	global_vars["PAL"]=True
+
 	# TODO change to allow a windows temp directory
+
 	if sys.platform=='win32':
-		t=os.path.split(os.path.split(home)[0])[0]+os.sep+"Local Settings"+os.sep+"Temp"+os.sep
-		global_vars["temp_folder"]= t#r'C:\temp'
+		global_vars["temp_folder"]=os.environ["TEMP"]
 	else:
 		global_vars["temp_folder"]="/var/tmp"
 	
 	print "Temp Directory is: " , global_vars["temp_folder"]
 	
 	if sys.platform=='win32':
-		home=os.path.split(os.path.split(home)[0])[0]+os.sep+".devede"
+		home+=os.sep + "Application Data" + os.sep + "devede" + os.sep + "devede.conf"
 	else:
 		home+=".devede"
 
 	print "home load: ", home
+	menuformat_found=False
 	try:
 		archivo=open(home,"r")
 		while True:
@@ -181,10 +188,20 @@ def load_config(global_vars):
 					global_vars["PAL"]=False
 			if linea[:12]=="temp_folder:":
 				global_vars["temp_folder"]=linea[12:]
+			if linea[:12]=="menu_format:":
+				if linea[12:]=="pal":
+					menuformat_found=True
+					global_vars["menu_PAL"]=True
+				if linea[12:]=="ntsc":
+					menuformat_found=True
+					global_vars["menu_PAL"]=False
 		archivo.close()
 	except IOError:
 		pass
 
+	if menuformat_found==False:
+		global_vars["menu_PAL"]=global_vars["PAL"] # if it's still not defined, we use the same format than the others
+
 
 def save_config(global_vars):
 
@@ -194,6 +211,10 @@ def save_config(global_vars):
 
 	if sys.platform=='win32':
 		home=os.path.split(os.path.split(home)[0])[0]+os.sep+".devede"
+		home+=os.sep + "Application Data" + os.sep + "devede"
+		if not os.path.isdir(home):
+			os.mkdir(home)
+		home+= os.sep + "devede.conf"
 	else:
 		home+=".devede"
 
@@ -206,6 +227,10 @@ def save_config(global_vars):
 		else:
 			archivo.write("video_format:ntsc\n")
 		archivo.write("temp_folder:"+global_vars["temp_folder"]+"\n")
+		if global_vars["menu_PAL"]:
+			archivo.write("menu_format:pal")
+		else:
+			archivo.write("menu_format:ntsc")
 		archivo.close()
 	except IOError:
 		pass
@@ -270,23 +295,46 @@ def get_new_param(parameters):
 
 
 def get_home_directory():
-	home=os.environ.get("HOME")
-	if not sys.platform == 'win32':
-		if home[-1]!="/": # /home/sane
-			home+="/" # /home/sane/
+	
+	if sys.platform == 'win32':
+		home=os.environ["USERPROFILE"]
 	else:
-		name='Personal'
-		SHELL_FOLDERS = r'Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders'
-		HKCU=_winreg.HKEY_CURRENT_USER
-		key=HKCU
-		subkey=SHELL_FOLDERS
-		key=_winreg.OpenKey(key,subkey)
-		ret=_winreg.QueryValueEx(key,name)
-		home=ret[0]
+		home=os.environ.get("HOME")
 
-		if home[-1]!=os.sep:
-			#home=os.path.join(home,"")
-			home=home+os.sep
+	if home[-1]!=os.sep:
+		home=home+os.sep
 
 	print home
 	return home
+
+
+def return_time(seconds,empty):
+
+	""" cuts a time in seconds into seconds, minutes and hours """
+
+	seconds2=int(seconds)
+
+	hours=str(seconds2/3600)
+	if empty:
+		if len(hours)==1:
+			hours="0"+hours
+	else:
+		if hours=="0":
+			hours=""
+	if hours!="":
+		hours+=":"
+	
+	minutes=str((seconds2/60)%60)
+	if empty or (hours!=""):
+		if len(minutes)==1:
+			minutes="0"+minutes
+	elif (minutes=="0") and (hours==""):
+			minutes=""
+	if minutes!="":
+		minutes+=":"
+
+	secs=str(seconds2%60)
+	if (len(secs)==1) and (minutes!=""):
+		secs="0"+secs
+
+	return hours+minutes+secs
